{% extends base_template_path %}
{% load powercrud %}
{% load partials %}

{% block content %}
    {% partial pcrud_content %}
{% endblock %}

{% partialdef pcrud_content %}
    <div class="card bg-base-100 shadow-xl">
        <div class="card-body">
            <h2 class="card-title bg-primary text-primary-content">{{ object }}</h2>
            {% object_detail object view %}
        </div>
    </div>
{% endpartialdef pcrud_content %}
